﻿Imports System.ComponentModel
Imports System.Windows.Forms
'''---------------------------------------------
''' <summary>
''' ユーザーコントロール（数値入力）
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
'''---------------------------------------------
Public Class BT_Number

#Region "コンスタント"

	Private CST_NUM_CHAR() As Char = New Char() {"0"c, "1"c, "2"c, "3"c, "4"c, "5"c, _
	   "6"c, "7"c, "8"c, "9"c}
	Private CST_DEC_CHAR() As Char = New Char() {"."c}
	Private CST_MIN_CHAR() As Char = New Char() {"-"c}
	Private CST_CMM_CHAR() As Char = New Char() {","c}

#End Region

#Region "変数"

	Private _caninput As Boolean = True			'True:入力可(通常表示),False:入力不可(ラベル表示)
	Private _comment As String = Nothing		'日本語での項目説明(検索条件保存で利用)
	Private _dblvalue As Double = 0				'入力値の数値型
	Private _maximum As String = 0				'最大値
	Private _minimum As String = 0				'最小値
	Private _decimalplaces As Double = 0		'小数点桁数
	Private _minusformat As Boolean = False		'マイナス入力フラグ（True：マイナス入力できる　False：マイナス入力できない）
	Private _commaformat As Boolean = False		'コンマ入力フラグ（True：コンマ表示する　False：コンマ表示しない）

#End Region

#Region "プロパティ"

	'''----------------------------------------
	''' <summary>
	''' 入力可・不可設定
	''' </summary>
	''' <value>True:入力可，False:入力不可</value>
	''' <returns>True:入力可，False:入力不可</returns>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("True:入力可，False:入力不可"), _
	DefaultValue(True), _
	Category("カスタムプロパティ")> _
	Public Property CanInput() As Boolean
		Get
			Return (_caninput)
		End Get
		Set(ByVal value As Boolean)
			_caninput = value
			If Me.DesignMode = False Then
				If _caninput = True Then				'入力可の場合、有効化
					Me.ReadOnly = False
					Me.TabStop = True
					BackColor = Nothing
				Else									'入力不可の場合、無効化
					Me.ReadOnly = True
					Me.TabStop = False
					BackColor = clsConst.CST_INACTIVE_BACK_COLOR
				End If
			End If
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 項目説明
	''' </summary>
	''' <value>項目説明</value>
	''' <returns>項目説明</returns>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("項目説明"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Comment() As String
		Get
			Return (_comment)
		End Get
		Set(ByVal value As String)
			_comment = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 入力値を数値型（Double）にした値
	''' </summary>
	''' <value>入力値を数値型（Double）にした値</value>
	''' <returns>入力値を数値型（Double）にした値</returns>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("入力値の数値型"), _
	DefaultValue(0), _
	Category("カスタムプロパティ")> _
	Public ReadOnly Property DblValue() As Double
		Get
			Return (_dblvalue)
		End Get
	End Property

	'''----------------------------------------
	''' <summary>
	''' 入力範囲（最大値）
	''' </summary>
	''' <value>入力範囲（最大値）</value>
	''' <returns>入力範囲（最大値）</returns>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("入力範囲（最大値）"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Maximum() As String
		Get
			Return (_maximum)
		End Get
		Set(ByVal value As String)
			_maximum = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 入力範囲（最小値）
	''' </summary>
	''' <value>入力範囲（最小値）</value>
	''' <returns>入力範囲（最小値）</returns>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("入力範囲（最大値）"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Minimum() As String
		Get
			Return (_minimum)
		End Get
		Set(ByVal value As String)
			_minimum = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 小数点桁数（０：整数　１以上：小数編集する）
	''' </summary>
	''' <value>小数点桁数（０：整数　１以上：小数編集する）</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/12 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("小数点桁数（０：整数　１以上：小数編集する）　※-1で小数点が不動"), _
	DefaultValue(0), _
	Category("カスタムプロパティ")> _
	Public Property DecimalPlaces() As Integer
		Get
			Return _decimalplaces
		End Get
		Set(ByVal value As Integer)
			_decimalplaces = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' マイナス入力フラグ（True：マイナス入力できる　False：マイナス入力できない）
	''' </summary>
	''' <value>マイナス入力フラグ（True：マイナス入力できる　False：マイナス入力できない）</value>
	''' <returns>マイナス入力フラグ（True：マイナス入力できる　False：マイナス入力できない）</returns>
	''' <remarks>
	''' 2010/10/12 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("マイナスを許可するかしないか"), _
	DefaultValue(False), _
	Category("カスタムプロパティ")> _
	Public Property MinusFormat() As Boolean
		Get
			Return _minusformat
		End Get
		Set(ByVal value As Boolean)
			_minusformat = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' コンマ入力フラグ（True：コンマ表示する　False：コンマ表示しない）
	''' </summary>
	''' <value>コンマ入力フラグ（True：コンマ表示する　False：コンマ表示しない）</value>
	''' <returns>コンマ入力フラグ（True：コンマ表示する　False：コンマ表示しない）</returns>
	''' <remarks>
	''' 2010/10/12 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("コンマ入力フラグ（True：コンマ表示する　False：コンマ表示しない）"), _
	DefaultValue(False), _
	Category("カスタムプロパティ")> _
	Public Property CommaFormat() As Boolean
		Get
			Return _commaformat
		End Get
		Set(ByVal value As Boolean)
			_commaformat = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' テキスト（カスタム化[Shadows]）
	''' ※数値を設定する（必ず）　Nothingはあり
	''' </summary>
	''' <value>テキスト</value>
	''' <returns>テキスト</returns>
	''' <remarks>
	''' 2010/10/12 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("テキスト（カスタム化[Shadows]）"), _
	Category("カスタムプロパティ")> _
	Public Shadows Property Text() As String
		Get
			Return MyBase.Text
		End Get
		Set(ByVal value As String)
			Try
				Dim pExpressions As String = "[^0-9\-\.\,]"			'数字、-、,、.以外を示す正規表現

				'空白でないならチェックする
				If Not String.IsNullOrEmpty(value) Then
					'正規表現をもとに入力チェック
					'カンマ入力対象でなければ正規表現から外す
					'マイナス入力対象でなければ正規表現から外す
					'少数入力対象でなければ正規表現から外す
					If Not _commaformat Then pExpressions = pExpressions.Replace("\,", "")
					If Not _minusformat Then pExpressions = pExpressions.Replace("\-", "")
					If _decimalplaces = 0 Then pExpressions = pExpressions.Replace("\.", "")
					If System.Text.RegularExpressions.Regex.IsMatch(value, pExpressions) Then
						'正しい入力値以外の入力が認められた時
						MyBase.Text = String.Empty
						_dblvalue = 0.0R
						Exit Property
					End If

					'数値でなければエラーとする
					If Not IsNumeric(value) Then
						'入力値が数値で無い場合
						MyBase.Text = String.Empty
						_dblvalue = 0.0R
						Exit Property
					End If

					'数値入力範囲のチェック
					If IsNumeric(Me._minimum) OrElse IsNumeric(Me._maximum) Then
						'最小値　、　最大値に入力があれば範囲チェックを行う
						Select Case True
							Case IsNumeric(Me._minimum) AndAlso IsNumeric(Me._maximum)
								'最小値、最大値ともに指定がある場合
								If Double.Parse(value) < Me._minimum OrElse Double.Parse(value) > Me._maximum Then
									'入力値が数値で無い場合
									MyBase.Text = String.Empty
									_dblvalue = 0.0R
									Exit Property
								End If
							Case IsNumeric(Me._minimum)
								'最小値に指定がある場合
								If Double.Parse(value) < Me._minimum Then
									'入力値が数値で無い場合
									MyBase.Text = String.Empty
									_dblvalue = 0.0R
									Exit Property
								End If
							Case IsNumeric(Me._maximum)
								'最大値に指定がある場合
								If Double.Parse(value) > Me._maximum Then
									'入力値が数値で無い場合
									MyBase.Text = String.Empty
									_dblvalue = 0.0R
									Exit Property
								End If
						End Select
					End If

					'マイナス表示を消す
					If Not _minusformat Then value = value.Replace("-", "")

					Select Case True
						Case _commaformat AndAlso _decimalplaces > 0
							'カンマ編集　＆　小数点指定がある場合
							MyBase.Text = Double.Parse(value).ToString("#,##0." & StrDup(Integer.Parse(_decimalplaces), "0"))
							_dblvalue = Double.Parse(MyBase.Text)
						Case _commaformat AndAlso _decimalplaces = -1
							'小数点指定がある場合
							If value.IndexOf(".") > -1 Then
								'小数点がみつからない
								MyBase.Text = Double.Parse(value).ToString("#,##0." & _
		 StrDup(Integer.Parse(value.Trim.Length - (value.Trim.IndexOf(".") + 1)), "0"))
							Else
								'小数点が見つかる
								MyBase.Text = Double.Parse(value).ToString("#,##0")
							End If
							_dblvalue = Double.Parse(MyBase.Text)
						Case _commaformat
							'小数点指定がある場合
							MyBase.Text = Double.Parse(value).ToString("#,##0")
							_dblvalue = Double.Parse(MyBase.Text)
						Case _decimalplaces > 0
							'カンマ編集
							MyBase.Text = String.Format("{0:0." & StrDup(Integer.Parse(_decimalplaces), "0") & "}", Double.Parse(value))
							_dblvalue = Double.Parse(MyBase.Text)
						Case _decimalplaces = -1
							MyBase.Text = value
							_dblvalue = Double.Parse(MyBase.Text)
						Case Else
							MyBase.Text = Double.Parse(value)
							_dblvalue = Double.Parse(MyBase.Text)
					End Select
				Else
					MyBase.Text = String.Empty
					_dblvalue = 0.0R
				End If
			Catch ex As Exception
			End Try
		End Set
	End Property

#End Region

#Region "メソッド"

	'''---------------------------------------------
	''' <summary>
	''' 入力した文字を判断して、チェックを行う
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub OnChar(ByVal e As System.Windows.Forms.KeyPressEventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnChar", "入力した文字を判断して、チェックを行う Start")
		End If
		Try
			If Char.IsControl(e.KeyChar) Then
				'制御文字は判断しない
				Return
			End If

			'数値チェック
			If System.Text.RegularExpressions.Regex.IsMatch(e.KeyChar.ToString, "[0-9]") Then
				'数値なのでOK
				Return
			End If

			'カンマチェック
			If _commaformat AndAlso System.Text.RegularExpressions.Regex.IsMatch(e.KeyChar.ToString, "[\,]") Then
				'カンマ有りでカンマが確認できたらOK
				Return
			End If

			'マイナスチェック
			If _minusformat AndAlso System.Text.RegularExpressions.Regex.IsMatch(e.KeyChar.ToString, "[\-]") Then
				'マイナス有りでマイナスが確認できたらOK
				Return
			End If

			'小数点チェック
			If (_decimalplaces > 0 OrElse _decimalplaces = -1) AndAlso System.Text.RegularExpressions.Regex.IsMatch(e.KeyChar.ToString, "[\.]") Then
				'小数点有りで小数点が確認できたらOK
				Return
			End If

			'有効な文字が確認できなかった場合
			e.Handled = True
			Return
		Catch ex As Exception
			Throw
		End Try
	End Sub

#End Region

#Region "オーバーライドメソッド"

	'''---------------------------------------------
	''' <summary>
	''' 編集開始時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnEnter(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnEnter", "編集開始 Start")
		End If
		Try
			MyBase.OnEnter(e)
			If Me.DesignMode = False AndAlso _caninput = True Then
				Me.BackColor = clsConst.CST_ACTIVE_BACK_COLOR			'背景色を変える
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集終了時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnLeave(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnLeave", "編集終了 Start")
		End If
		Try
			MyBase.OnLeave(e)
			If Me.DesignMode = False AndAlso _caninput = True Then
				Me.BackColor = Nothing			'背景色を戻す
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 入力値の検査
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/12 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnValidating(ByVal e As System.ComponentModel.CancelEventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnValidating", "入力値の検査処理 Start")
		End If
		Dim pExpressions As String = "[^0-9\-\.\,]"			'数字、-、,、.以外を示す正規表現
		Try
			MyBase.OnValidating(e)

			'デザインモード中はなにもしない
			If Me.DesignMode Then Exit Try

			'Validateを行わない場合はチェック処理終了
			If CType(Me.TopLevelControl, frmBase).ActiveControl.CausesValidation = False Then
				Exit Sub
			End If

			'空白でないならチェックする
			If Not String.IsNullOrEmpty(MyBase.Text) Then
				'正規表現をもとに入力チェック
				'カンマ入力対象でなければ正規表現から外す
				'マイナス入力対象でなければ正規表現から外す
				'少数入力対象でなければ正規表現から外す
				If Not _commaformat Then pExpressions = pExpressions.Replace("\,", "")
				If Not _minusformat Then pExpressions = pExpressions.Replace("\-", "")
				If _decimalplaces = 0 Then pExpressions = pExpressions.Replace("\.", "")
				If System.Text.RegularExpressions.Regex.IsMatch(MyBase.Text, pExpressions) Then
					'正しい入力値以外の入力が認められた時
					CType(Me.TopLevelControl, frmBase).showMsgBar("S0022", frmBase.Enum_MsgIcon.Err)	 '数値を入力してください。
					CType(Me.TopLevelControl, frmBase)._validateCtl = Me
					e.Cancel = True
					Exit Sub
				End If

				'数値でなければエラーとする
				If Not IsNumeric(MyBase.Text) Then
					'入力値が数値で無い場合
					CType(Me.TopLevelControl, frmBase).showMsgBar("S0022", frmBase.Enum_MsgIcon.Err)	 '数値を入力してください。
					CType(Me.TopLevelControl, frmBase)._validateCtl = Me
					e.Cancel = True
					Exit Sub
				End If

				'数値入力範囲のチェック
				If IsNumeric(Me._minimum) OrElse IsNumeric(Me._maximum) Then
					'最小値　、　最大値に入力があれば範囲チェックを行う
					Select Case True
						Case IsNumeric(Me._minimum) AndAlso IsNumeric(Me._maximum)
							'最小値、最大値ともに指定がある場合
							If Double.Parse(MyBase.Text) < Me._minimum OrElse Double.Parse(MyBase.Text) > Me._maximum Then
								'入力値が数値で無い場合
								CType(Me.TopLevelControl, frmBase).showMsgBar("S0019", frmBase.Enum_MsgIcon.Err, Me._minimum.ToString, Me._maximum.ToString, Nothing)	 '○○から××の間で入力してくだしさい。
								CType(Me.TopLevelControl, frmBase)._validateCtl = Me
								e.Cancel = True
								Exit Sub
							End If
						Case IsNumeric(Me._minimum)
							'最小値に指定がある場合
							If Double.Parse(MyBase.Text) < Me._minimum Then
								'入力値が数値で無い場合
								CType(Me.TopLevelControl, frmBase).showMsgBar("S0020", frmBase.Enum_MsgIcon.Err, Me._minimum.ToString, Nothing)	 '○○以上の数値を入力してください。
								CType(Me.TopLevelControl, frmBase)._validateCtl = Me
								e.Cancel = True
								Exit Sub
							End If
						Case IsNumeric(Me._maximum)
							'最大値に指定がある場合
							If Double.Parse(MyBase.Text) > Me._maximum Then
								'入力値が数値で無い場合
								CType(Me.TopLevelControl, frmBase).showMsgBar("S0021", frmBase.Enum_MsgIcon.Err, Me._maximum.ToString, Nothing)	 '××以下の数値を入力してください。
								CType(Me.TopLevelControl, frmBase)._validateCtl = Me
								e.Cancel = True
								Exit Sub
							End If
					End Select
				End If

				'マイナス表示を消す
				If Not _minusformat Then MyBase.Text = MyBase.Text.Replace("-", "")

				Select Case True
					Case _commaformat AndAlso _decimalplaces > 0
						'カンマ編集　＆　小数点指定がある場合
						MyBase.Text = Double.Parse(MyBase.Text).ToString("#,##0." & StrDup(Integer.Parse(_decimalplaces), "0"))
						_dblvalue = Double.Parse(MyBase.Text)
					Case _commaformat AndAlso _decimalplaces = -1
						'小数点指定がある場合
						If MyBase.Text.IndexOf(".") > -1 Then
							'小数点がみつからない
							MyBase.Text = Double.Parse(MyBase.Text).ToString("#,##0." & _
							 StrDup(Integer.Parse(MyBase.Text.Trim.Length - (MyBase.Text.Trim.IndexOf(".") + 1)), "0"))
						Else
							'小数点が見つかる
							MyBase.Text = Double.Parse(MyBase.Text).ToString("#,##0")
						End If
						_dblvalue = Double.Parse(MyBase.Text)
					Case _commaformat
						'小数点指定がある場合
						MyBase.Text = Double.Parse(MyBase.Text).ToString("#,##0")
						_dblvalue = Double.Parse(MyBase.Text)
					Case _decimalplaces > 0
						'カンマ編集
						MyBase.Text = String.Format("{0:0." & StrDup(Integer.Parse(_decimalplaces), "0") & "}", Double.Parse(MyBase.Text))
						_dblvalue = Double.Parse(MyBase.Text)
					Case _decimalplaces = -1
						MyBase.Text = MyBase.Text
						_dblvalue = Double.Parse(MyBase.Text)
					Case Else
						MyBase.Text = Double.Parse(MyBase.Text)
						_dblvalue = Double.Parse(MyBase.Text)
				End Select
			Else
				MyBase.Text = String.Empty
				_dblvalue = 0.0R
			End If

			If Not CType(Me.TopLevelControl, frmBase)._validateFlg Then
				'_validateFlg=Falseが通常。　Trueの場合はForm.ValidateChildren実行中
				CType(Me.TopLevelControl, frmBase).clearMsgBar()			'メッセージクリア
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' キープレスチェック
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnKeyPress(ByVal e As System.Windows.Forms.KeyPressEventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnKeyPress", "キープレスチェック Start")
		End If
		Try
			Me.OnChar(e)
			If e.Handled Then
				Return
			End If
			MyBase.OnKeyPress(e)
		Catch ex As Exception
			Throw
		End Try
	End Sub

#End Region

End Class
