﻿Imports System.ComponentModel
Imports System.Windows.Forms
'''---------------------------------------------
''' <summary>
''' ユーザーコントロール（NumericUpDown）
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
'''---------------------------------------------
Public Class BT_NumericUpDown

#Region "変数"

	Private _caninput As Boolean = True		'True:入力可(通常表示),False:入力不可(ラベル表示)
	Private _comment As String = Nothing	'日本語での項目説明(検索条件保存で利用)
	Private _required As Boolean = False	'必須入力でない
	Private _text As String = Nothing
	Private oldReadOnly As Boolean
	Private oldIncrement As Integer

#End Region

#Region "プロパティ"

	'''----------------------------------------
	''' <summary>
	''' テキストプロパティ
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("テキストプロパティ"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Shadows Property Text() As String
		Get
			Return CType(Me, Control).Text
		End Get
		Set(ByVal value As String)
			If IsNumeric(value) Then
				Me.Value = value
			Else
				Me.Value = Me.Minimum
			End If

			If String.IsNullOrEmpty(value) Then
				CType(Me, Control).Text = value
			Else
				CType(Me, Control).Text = Me.Value
			End If
			'CType(Me, Control).Text = Me.Value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' テキストプロパティ
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("Valueプロパティ"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Shadows Property Value() As Decimal
		Get
			Return MyBase.Value
		End Get
		Set(ByVal value As Decimal)
			If IsNumeric(value) Then
				Select Case True
					Case Me.Maximum < value
						MyBase.Value = Me.Maximum
					Case Me.Minimum > value
						MyBase.Value = Me.Minimum
					Case Else
						MyBase.Value = value
				End Select
			Else
				MyBase.Value = Me.Minimum
			End If
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 入力可・不可設定
	''' </summary>
	''' <value>True:入力可，False:入力不可</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("True:入力可，False:入力不可"), _
	DefaultValue(True), _
	Category("カスタムプロパティ")> _
	Public Property CanInput() As Boolean
		Get
			Return (_caninput)
		End Get
		Set(ByVal value As Boolean)
			_caninput = value
			If Me.DesignMode = False Then
				If _caninput = True Then				'入力可の場合、有効化
					Me.ReadOnly = Me.oldReadOnly
					Me.Increment = Me.oldIncrement
					Me.TabStop = True
					Me.BackColor = System.Drawing.SystemColors.Window
				Else									'入力不可の場合、無効化
					Me.oldReadOnly = Me.ReadOnly
					Me.ReadOnly = True
					Me.oldIncrement = Me.Increment
					Me.Increment = 0
					Me.TabStop = False
					Me.BackColor = clsConst.CST_INACTIVE_BACK_COLOR
				End If
			End If
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 項目説明
	''' </summary>
	''' <value>項目説明</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("項目説明"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Comment() As String
		Get
			Return (_comment)
		End Get
		Set(ByVal value As String)
			_comment = value
		End Set
	End Property

	'''---------------------------------------------
	''' <summary>
	''' 必須入力フラグ(True:必須入力である、False：必須入力でない)
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2009/12/23 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	<Description("必須入力の場合Trueを指定します。"), _
	DefaultValue(False), _
	Category("カスタムプロパティ")> _
	Public Property Required() As Boolean
		Get
			Return _required
		End Get
		Set(ByVal value As Boolean)
			_required = value
		End Set
	End Property

#End Region

#Region "オーバーライドメソッド"

	'''---------------------------------------------
	''' <summary>
	''' 編集開始時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnEnter(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnEnter", "編集開始 Start")
		End If
		Try
			MyBase.OnEnter(e)
			If Not Me.DesignMode AndAlso _caninput = True Then
				Me.BackColor = clsConst.CST_ACTIVE_BACK_COLOR			'背景色を変える
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集終了時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnLeave(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnLeave", "編集終了 Start")
		End If
		Try
			MyBase.OnLeave(e)
			If Not Me.DesignMode AndAlso _caninput = True Then
				Me.BackColor = Nothing			'背景色を戻す
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集終了（Validate）
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/09/30 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnValidating(ByVal e As System.ComponentModel.CancelEventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnValidating", "編集終了（Validate） Start")
		End If
		Try
			If Me._required AndAlso String.IsNullOrEmpty(CType(Me, Control).Text) Then
				Me.Value = Me.Minimum						'メモリ内の値もMe.Minimumに設定する
				CType(Me, Control).Text = Me.Minimum		'表示の値も    Me.Minimumに設定する
			End If

			If Not String.IsNullOrEmpty(CType(Me, Control).Text) Then
				'数値以外が入力されている場合
				If Not IsNumeric(CType(Me, Control).Text) Then
					Me.Value = Me.Minimum						'メモリ内の値もMe.Minimumに設定する
					CType(Me, Control).Text = Me.Minimum		'表示の値も    Me.Minimumに設定する
				End If

				'最小値のチェック
				If IsNumeric(CType(Me, Control).Text) AndAlso Me.Minimum > Double.Parse(CType(Me, Control).Text) Then
					Me.Value = Me.Minimum						'メモリ内の値もMe.Minimumに設定する
					CType(Me, Control).Text = Me.Minimum		'表示の値も    Me.Minimumに設定する
				End If

				'最大値のチェック
				If IsNumeric(CType(Me, Control).Text) AndAlso Me.Maximum < Double.Parse(CType(Me, Control).Text) Then
					Me.Value = Me.Maximum						'メモリ内の値もMe.Minimumに設定する
					CType(Me, Control).Text = Me.Maximum		'表示の値も    Me.Minimumに設定する
				End If
			End If
			MyBase.OnValidating(e)
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

#End Region

End Class
