﻿Imports XCM
Imports XSP

''' ---------------------------------------------
''' <summary>
''' マスタメンテ共通処理クラス（新規作成：V4-14028）
''' </summary>
''' <remarks>
''' Copyright 2013 FUJITSU SYSTEMS WEST LIMITED All rights reserved.<BR/>
''' FUJITSU SYSTEMS WEST LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class clsMstMenteCom
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub

#End Region

#Region "コンスタント"
	'ソートグリフ幅補正値
	Public Const C_SORTGLYPH_WIDTH As Integer = 12
	'マージン幅
	Public Const C_MARGIN_WIDTH As Integer = 8
	'グリッド補正幅
	Public Const C_GRIDVSCROLL_WIDTH As Integer = 20
	'グリッドヘッダ高
	Public Const C_GRIDHEADER_HEIGHT As Integer = 25
	'グリッドデータ高
	Public Const C_GRIDDATA_HEIGHT As Integer = 22
#End Region

#Region "変数"
	' フォーム
	Public _Frm As XMS000F020
	' フォーム（全件入力）
	Public _FrmAllEnt As XMS000F040

	' 前回検索SQL文保存
	Public strPrevSql As String
	' 前回検索パラメータ保存
	Public aryPrevParam As ArrayList
	' 前回検索DBタイプ保存
	Public aryPrevDBType As ArrayList
	' 前回検索値保存
	Public aryPrevValue As ArrayList

#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pFrm"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal pFrm As XMS000F020)
		_Frm = pFrm
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ（前回検索値初期化）
	''' </summary>
	''' <param name="pFrm"></param>
	''' <param name="bClear"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal pFrm As XMS000F020, ByVal bClear As Boolean)
		Try
			_Frm = pFrm
			If bClear Then
				strPrevSql = String.Empty
				aryPrevParam = New ArrayList
				aryPrevDBType = New ArrayList
				aryPrevValue = New ArrayList
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pFrm"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal pFrm As XMS000F040)
		_FrmAllEnt = pFrm
	End Sub

#End Region

#Region "メソッド"

#Region "明細一覧形式"

	''' ---------------------------------------------
	''' <summary>
	''' 画面クリア
	''' </summary>
	''' <param name="bSearchKeyClear"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub clearScreen(Optional ByVal bSearchKeyClear As Boolean = True)
		Dim cliCom As clsCom = Nothing
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If
			'画面クリア
			cliCom = New clsCom
			For Each col As clsColumn In _Frm.Columns
				If col.UpdateItem AndAlso _
					col.Control IsNot Nothing Then
					If Not bSearchKeyClear Then
						If Not col.SearchItem Then
							If TypeOf col.Control Is BT_MultiComboBox Then
								cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), String.Empty)
							Else
								col.Control.Text = String.Empty
							End If
						End If
					Else
						If TypeOf col.Control Is BT_MultiComboBox Then
							cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), String.Empty)
						Else
							col.Control.Text = String.Empty
						End If
					End If
				End If
			Next
		Catch ex As Exception
			Throw
		Finally
			cliCom = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' グリッドデータ設定
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setDataToGrid()
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					' 検索なし
					' マスタデータ取得SQL文作成
					Dim strSql As String
					Dim strPrimaryKeyItem As String = getOrderString()
					If String.IsNullOrEmpty(_Frm.SelectText) Then
						Dim strOrder As String = String.Empty
						Dim strItem As String = getItemString()

						If Not String.IsNullOrEmpty(strPrimaryKeyItem) Then
							strOrder = String.Format(sqlMstMenteCom.sqlOrder, strPrimaryKeyItem)
						End If
						strSql = String.Format(sqlMstMenteCom.sqlSelect, strItem, _Frm.TableName, strOrder)
					Else
						strSql = String.Format(sqlMstMenteCom.sqlSelectFixed, _Frm.SelectText, String.Format(sqlMstMenteCom.sqlOrder, strPrimaryKeyItem))
					End If

					.setSQLDa(strSql)
					.execQueryDa(dt)
				End With
				_Frm.dgv001XMS000F020.DataSource = dt
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' グリッドデータ設定（前回検索より）
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setDataToGridFromPrev()
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					' 検索
					If Not String.IsNullOrEmpty(strPrevSql) AndAlso
						aryPrevParam IsNot Nothing AndAlso
						aryPrevDBType IsNot Nothing AndAlso
						aryPrevValue IsNot Nothing Then
						.setSQLDa(strPrevSql)
						For i As Integer = 0 To aryPrevParam.Count - 1
							.setParamDa(aryPrevParam(i), CType(aryPrevDBType(i), Integer))
							.setValDa(aryPrevParam(i), aryPrevValue(i))
						Next
						.execQueryDa(dt)
					End If
				End With
				_Frm.dgv001XMS000F020.DataSource = dt
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' グリッドデータ設定（検索より）
	''' </summary>
	''' <param name="bScreenClear"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function setDataToGridFromSearch(Optional ByVal bScreenClear As Boolean = True) As clsMstMenteCom
		Dim cliPrevSearch As clsMstMenteCom
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			' マスタデータ取得
			Dim strSql As String
			Dim strOrder As String = String.Empty
			Dim strItem As String = getItemString()
			Dim strWhere As String = getSearchString()
			Dim strPrimaryKeyItem As String = getOrderString()

			If Not String.IsNullOrEmpty(strPrimaryKeyItem) Then
				strOrder = String.Format(sqlMstMenteCom.sqlOrder, strPrimaryKeyItem)
			End If
			If String.IsNullOrEmpty(_Frm.SelectText) Then
				strSql = String.Format(sqlMstMenteCom.sqlSelectSearch, strItem, _Frm.TableName, strWhere, strOrder)
			Else
				strSql = String.Format(sqlMstMenteCom.sqlSelectSearchFixed, _Frm.SelectText, strWhere, strOrder)
			End If
			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					.setSQLDa(strSql)
					'パラメータ設定＆検索SQL関連保存
					cliPrevSearch = setSqlParamSearchDa(db)
					cliPrevSearch.strPrevSql = strSql
					'実行
					.execQueryDa(dt)
				End With
				_Frm.dgv001XMS000F020.DataSource = dt
			End Using
			'検索条件クリア
			If bScreenClear Then
				clearScreen()
			End If

			Return cliPrevSearch

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' データテーブル取得（汎用）
	''' </summary>
	''' <param name="SearchColumns"></param> 
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataTable(ByVal SearchColumns As clsColumnCollection) As DataTable
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			' マスタデータ取得
			Dim strOrder As String = String.Empty
			Dim strItem As String = getItemString()
			Dim strWhere As String = getSearchString()
			Dim strPrimaryKeyItem As String = getOrderString()

			If Not String.IsNullOrEmpty(strPrimaryKeyItem) Then
				strOrder = String.Format(sqlMstMenteCom.sqlOrder, strPrimaryKeyItem)
			End If

			Dim strSql As String = String.Format(sqlMstMenteCom.sqlSelectSearch, strItem, _Frm.TableName, strWhere, strOrder)
			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					.setSQLDa(strSql)
					'実行
					setSqlParamWhereAllDa(db)
					.execQueryDa(dt)
				End With

				Return dt

			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ツールチップ設定
	''' </summary>
	''' <param name="ttp"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setToolTips(ByVal ttp As ToolTip)
		Try
			If _Frm.Columns Is Nothing OrElse _
			_Frm.Columns.Count <= 0 Then
				Return
			End If
			ttp = New ToolTip()
			ttp.ShowAlways = True
			For Each col As clsColumn In _Frm.Columns
				If Not String.IsNullOrEmpty(col.ToolTipText) AndAlso _
					 col.Control IsNot Nothing Then
					ttp.SetToolTip(col.Control, col.ToolTipText)
				End If
			Next
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 検索画面判定
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function isSearch() As Boolean
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return False
			End If
			For Each col As clsColumn In _Frm.Columns
				If col.SearchItem Then
					Return True
				End If
			Next
			Return False
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 必須チェック
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function isRequired() As Boolean
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return False
			End If

			If Not _Frm.ValidateChildren() Then
				Return False
			End If
			For Each col As clsColumn In _Frm.Columns
				If col.Required Then
					If String.IsNullOrEmpty(GetValue(col.Control)) Then
						DirectCast(_Frm, frmBase).addErrList("E0001", col.Control.Name, col.Caption, Nothing)
					End If
				End If
			Next
			If DirectCast(_Frm, frmBase).getErrCount() > 0 Then
				Return False
			Else
				Return True				'エラーがない場合、正常終了
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' データ取得処理
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function selectData() As Boolean
		Dim bRet As Boolean = True
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return False
			End If

			Dim strOrder As String = String.Empty
			Dim strItem As String = getItemString()
			Dim strWhere As String = getWhereString()

			Dim strSql As String = String.Format(sqlMstMenteCom.sqlSelect, strItem, _Frm.TableName, strWhere)
			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					.setSQLDa(strSql)
					setSqlParamWhereDa(db)
					.execQueryDa(dt)
				End With
				If dt Is Nothing OrElse _
					dt.Rows.Count <= 0 Then
					bRet = False
				End If
			End Using

			Return bRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' データ更新処理
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub modifyData(ByVal db As clsDB)
		Try
			'データ存在チェック
			If selectData() Then
				'更新
				updateData(db)
			Else
				'登録
				insertData(db)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 更新処理
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub updateData(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim strItem As String = getUpdateItemString()
			Dim strWhere As String = getWhereString()

			Dim strSql As String = String.Format(sqlMstMenteCom.sqlUpdate, _Frm.TableName, strItem, strWhere)
			With db
				.setSQL(strSql)
				setSqlParam(db)
				.execNonQuery(False)
			End With
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 登録処理
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub insertData(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count < 0 Then
				Return
			End If

			Dim strItem As String = getItemString() & sqlMstMenteCom.sqlFIXED_ITEM
			Dim strValue As String = getInsertItemString()

			Dim strSql As String = String.Format(sqlMstMenteCom.sqlInsert, _Frm.TableName, strItem, strValue)
			With db
				.setSQL(strSql)
				setSqlParam(db)
				.execNonQuery(False)
			End With
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 削除処理
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub deleteData(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim strWhere As String = getWhereString()
			Dim strSql As String = String.Format(sqlMstMenteCom.sqlDelete, _Frm.TableName, strWhere)
			With db
				.setSQL(strSql)
				setSqlParamWhere(db)
				.execNonQuery(False)
			End With
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－項目名文字列作成（SELECT,INSERT）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getItemString() As String
		Dim strRet As String = String.Empty
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count < 0 Then
				Return Nothing
			End If

			For Each col As clsColumn In _Frm.Columns
				If col.UpdateItem Then
					strRet &= col.ColumnName & ","
				End If
			Next
			strRet = strRet.Substring(0, strRet.Length - 1)

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－項目名文字列作成（UPDATE）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getUpdateItemString() As String
		Dim strRet As String = String.Empty
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			For Each col As clsColumn In _Frm.Columns
				If col.UpdateItem Then
					iCount += 1
					strParam = sqlMstMenteCom.prmItem & col.ColumnName
					strRet &= String.Format(sqlMstMenteCom.sqlUpdateItem, col.ColumnName, strParam) & ","
				End If
			Next
			strRet &= String.Format(sqlMstMenteCom.sqlUpdateItem, sqlMstMenteCom.itmLASTUPDUSER_CD, sqlMstMenteCom.prmLASTUPDUSER_CD) & ","
			strRet &= String.Format(sqlMstMenteCom.sqlUpdateItem, sqlMstMenteCom.itmLASTUPD_DT, sqlMstMenteCom.prmLASTUPD_DT)

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－項目名文字列作成（INSERT VALUE）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getInsertItemString() As String
		Dim strRet As String = String.Empty
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			Dim iCount As Integer = 0
			For Each col As clsColumn In _Frm.Columns
				If col.UpdateItem Then
					iCount += 1
					strRet &= sqlMstMenteCom.prmItem & col.ColumnName & ","
				End If
			Next
			strRet &= sqlMstMenteCom.sqlFIXED_PARAM

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＯＲＤＥＲ文字列作成
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getOrderString() As String
		Dim strRet As String = String.Empty
		Dim srtDic As SortedDictionary(Of Integer, String)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			srtDic = New SortedDictionary(Of Integer, String)
			For Each col As clsColumn In _Frm.Columns
				If col.SortItemNo > 0 AndAlso
					col.SortOrder <> clsColumn.ENUM_SORT_ORDER.None Then
					srtDic.Add(col.SortItemNo, col.ColumnName & Space(1) & col.SortOrder.ToString)
				End If
			Next
			For Each kv As KeyValuePair(Of Integer, String) In srtDic
				strRet &= kv.Value & ","
			Next
			If strRet.Length > 0 Then
				strRet = strRet.Substring(0, strRet.Length - 1)
			End If

			Return strRet

		Catch ex As Exception
			Throw
		Finally
			srtDic = Nothing
		End Try
	End Function
	Private Function fSort(ByVal kvp1 As KeyValuePair(Of Integer, String),
						  ByVal kvp2 As KeyValuePair(Of Integer, String)) As Integer
		Try
			Return kvp2.Value - kvp1.Value
		Catch ex As Exception
			Throw
		End Try
  End Function


	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥ文字列作成
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getWhereString() As String
		Dim strRet As String = String.Empty
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			For Each col As clsColumn In _Frm.Columns
				If col.PrimaryKey Then
					iCount += 1
					strParam = sqlMstMenteCom.prmItem & col.ColumnName
					If iCount = 1 Then
						strRet &= String.Format(sqlMstMenteCom.sqlWhere, col.ColumnName, strParam)
					Else
						strRet &= String.Format(sqlMstMenteCom.sqlWhereAnd, col.ColumnName, strParam)
					End If
				End If
			Next

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥ文字列作成（検索）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getSearchString() As String
		Dim strRet As String = String.Empty
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			For Each col As clsColumn In _Frm.Columns
				'データ入力有り
				If Not String.IsNullOrEmpty(GetValue(col.Control).Trim) Then
					'検索項目
					If col.SearchItem Then
						iCount += 1
						'Where文作成
						strParam = sqlMstMenteCom.prmItem & col.ColumnName
						If iCount = 1 Then
							If col.SearchLike Then
								strRet &= String.Format(sqlMstMenteCom.sqlWhereLike, col.ColumnName, strParam)
							Else
								strRet &= String.Format(sqlMstMenteCom.sqlWhere, col.ColumnName, strParam)
							End If
						Else
							If col.SearchLike Then
								strRet &= String.Format(sqlMstMenteCom.sqlWhereAndLike, col.ColumnName, strParam)
							Else
								strRet &= String.Format(sqlMstMenteCom.sqlWhereAnd, col.ColumnName, strParam)
							End If
						End If
					End If
				End If
			Next

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥパラメータ作成
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParamWhere(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			With db
				For Each col As clsColumn In _Frm.Columns
					If col.PrimaryKey Then
						iCount += 1
						strParam = sqlMstMenteCom.prmItem & col.ColumnName
						.setParam(strParam, CType(col.DbType, Integer))
						.setVal(strParam, GetValue(col.Control))
					End If
				Next
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥパラメータ作成（DataTable）
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParamWhereDa(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			With db
				For Each col As clsColumn In _Frm.Columns
					If col.PrimaryKey Then
						iCount += 1
						strParam = sqlMstMenteCom.prmItem & col.ColumnName
						.setParamDa(strParam, CType(col.DbType, Integer))
						.setValDa(strParam, GetValue(col.Control))
					End If
				Next
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥパラメータ作成（汎用）
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParamWhereAllDa(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			With db
				For Each col As clsColumn In _Frm.Columns
					iCount += 1
					strParam = sqlMstMenteCom.prmItem & col.ColumnName
					.setParamDa(strParam, CType(col.DbType, Integer))
					.setValDa(strParam, GetValue(col.Control))
				Next
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＷＨＥＲＥパラメータ作成（検索）
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function setSqlParamSearchDa(ByVal db As clsDB) As clsMstMenteCom
		Dim cliPrevSearch As clsMstMenteCom
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return Nothing
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			cliPrevSearch = New clsMstMenteCom(_Frm, True)
			With db
				For Each col As clsColumn In _Frm.Columns
					'データ入力有り
					If Not String.IsNullOrEmpty(GetValue(col.Control).Trim) Then
						'検索項目
						If col.SearchItem Then
							'パラメータ設定
							iCount += 1
							strParam = sqlMstMenteCom.prmItem & col.ColumnName
							.setParamDa(strParam, CType(col.DbType, Integer))
							'パラメータ名保存
							cliPrevSearch.aryPrevParam.Add(strParam)
							cliPrevSearch.aryPrevDBType.Add(col.DbType)
							If col.SearchLike Then
								.setValDa(strParam, sqlMstMenteCom.CST_LIKE & GetValue(col.Control) & sqlMstMenteCom.CST_LIKE)
								'値保存
								cliPrevSearch.aryPrevValue.Add(sqlMstMenteCom.CST_LIKE & GetValue(col.Control) & sqlMstMenteCom.CST_LIKE)
							Else
								.setValDa(strParam, GetValue(col.Control))
								'値保存
								cliPrevSearch.aryPrevValue.Add(GetValue(col.Control))
							End If
						End If
					End If
				Next
			End With
			Return cliPrevSearch
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－パラメータ作成
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParam(ByVal db As clsDB)
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If

			Dim iCount As Integer = 0
			Dim strParam As String
			Dim strValue As String
			With db
				For Each col As clsColumn In _Frm.Columns
					If col.UpdateItem Then
						iCount += 1
						strParam = sqlMstMenteCom.prmItem & col.ColumnName
						.setParam(strParam, CType(col.DbType, Integer))
						strValue = GetValue(col.Control)
						.setVal(strParam, strValue)
					End If
				Next
				' 固定項目
				.setParam(sqlMstMenteCom.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMstMenteCom.prmLASTUPDUSER_CD, CType(_Frm, frmBase)._userID)
				.setParam(sqlMstMenteCom.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMstMenteCom.prmLASTUPD_DT, Now)
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' グリッドのデータを画面に編集
	''' </summary>
	''' <param name="bSearchOnly"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setDataFromGrid(Optional ByVal bSearchOnly As Boolean = False)
		Dim cliCom As clsCom = Nothing
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If
			If _Frm.dgv001XMS000F020.CurrentRow.Index < 0 Then Return
			cliCom = New clsCom
			For Each col As clsColumn In _Frm.Columns
				If col.Control IsNot Nothing Then
					If bSearchOnly Then
						If col.SearchItem Then
							If TypeOf col.Control Is BT_MultiComboBox Then
								cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), _Frm.dgv001XMS000F020.Rows(_Frm.dgv001XMS000F020.CurrentRow.Index).Cells(col.ColumnName).Value.ToString)
							Else
								col.Control.Text = _Frm.dgv001XMS000F020.Rows(_Frm.dgv001XMS000F020.CurrentRow.Index).Cells(col.ColumnName).Value.ToString
							End If
						End If
					Else
						If Not col.SearchItem Then
							If TypeOf col.Control Is BT_MultiComboBox Then
								cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), _Frm.dgv001XMS000F020.Rows(_Frm.dgv001XMS000F020.CurrentRow.Index).Cells(col.ColumnName).Value.ToString)
							Else
								col.Control.Text = _Frm.dgv001XMS000F020.Rows(_Frm.dgv001XMS000F020.CurrentRow.Index).Cells(col.ColumnName).Value.ToString
							End If
						End If
					End If
				End If
			Next
		Catch ex As Exception
			Throw
		Finally
			cliCom = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' フォカスを先頭に移動
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setFocus()
		Try
			If _Frm.Columns Is Nothing OrElse _
				_Frm.Columns.Count <= 0 Then
				Return
			End If
			For Each col As clsColumn In _Frm.Columns
				If col.Control.Enabled Then
					col.Control.Select()
					Exit For
				End If
			Next
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' プライマリーキーの値が一致する行選択
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub selectRow()
		Dim iFirstColumn As Integer = -1
		Dim iIdx As Integer = -1
		Dim bSelected As Boolean = False
		Try
			If _Frm.dgv001XMS000F020.Rows Is Nothing OrElse _
				_Frm.dgv001XMS000F020.Rows.Count <= 0 Then
				Return
			End If
			Dim iPrimaryKeyCount As Integer = 0
			For Each drow As DataGridViewRow In _Frm.dgv001XMS000F020.Rows
				Dim bFind As Boolean = True
				For Each col As clsColumn In _Frm.Columns
					iIdx += 1
					If col.PrimaryKey Then
						iPrimaryKeyCount += 1
						If GetValue(col.Control) <> drow.Cells(col.ColumnName).Value.ToString Then
							bFind = False
						End If
					End If
					If col.Visible Then
						If iFirstColumn <= -1 Then
							iFirstColumn = iIdx
						End If
					End If
				Next
				If bFind AndAlso _
					iPrimaryKeyCount > 0 Then
					drow.Selected = True
					bSelected = True
					If Not _Frm.dgv001XMS000F020.Rows(drow.Index).Displayed AndAlso
						_Frm.dgv001XMS000F020.Rows(drow.Index).Visible Then
						_Frm.dgv001XMS000F020.FirstDisplayedScrollingRowIndex = drow.Index
						If iFirstColumn > -1 Then
							_Frm.dgv001XMS000F020.FirstDisplayedScrollingColumnIndex = iFirstColumn
						End If
					End If
					Exit For
				End If
			Next
			If Not bSelected Then
				_Frm.dgv001XMS000F020.ClearSelection()
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 列を選択とデータの画面設定
	''' </summary>
	''' <remarks>
	''' 2013/07/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub selectRowFromData()
		Dim cliCom As clsCom = Nothing
		Try
			cliCom = New clsCom
			'プライマリキー項目が全て入力されている。
			Using cliMstMenteCom As New clsMstMenteCom(_Frm)
				cliMstMenteCom.selectRow()
			End Using
			If _Frm.dgv001XMS000F020.SelectedRows IsNot Nothing AndAlso
				_Frm.dgv001XMS000F020.SelectedRows.Count > 0 Then
				'選択されている
				For Each col As clsColumn In _Frm.Columns
					If Not col.PrimaryKey AndAlso
						col.UpdateItem Then
						'プライマリキー以外の値を設定
						If TypeOf col.Control Is BT_MultiComboBox Then
							cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), _Frm.dgv001XMS000F020.SelectedRows(0).Cells(col.ColumnName).Value.ToString)
						Else
							col.Control.Text = _Frm.dgv001XMS000F020.SelectedRows(0).Cells(col.ColumnName).Value.ToString
						End If
					End If
				Next
				_Frm.btn007XMS000F010.Enabled = True
			Else
				'選択されていない
				For Each col As clsColumn In _Frm.Columns
					If Not col.PrimaryKey AndAlso
						col.UpdateItem Then
						'プライマリキー以外の値をクリア
						If TypeOf col.Control Is BT_MultiComboBox Then
							cliCom.setComboValue(DirectCast(col.Control, BT_MultiComboBox), String.Empty)
						Else
							col.Control.Text = String.Empty
						End If
					End If
				Next
				_Frm.btn007XMS000F010.Enabled = False
			End If
		Catch ex As Exception
			Throw
		Finally
			cliCom = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コントロールの値取得
	''' </summary>
	''' <param name="ctl"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function GetValue(ByVal ctl As Control) As String
		Try
			If ctl IsNot Nothing Then
				If TypeOf ctl Is BT_Mask Then
					Return DirectCast(ctl, BT_Mask).Text.Trim
				Else
					Return ctl.Text
				End If
			Else
				Return String.Empty
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' カラム名称よりカラムクラス取得
	''' </summary>
	''' <param name="ColumnName"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2013/05/08 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMstMenteColumn(ByVal ColumnName As String) As clsColumn
		Try
			For Each col As clsColumn In _Frm.Columns
				If col.ColumnName = ColumnName Then
					Return col
				End If
			Next
			Return Nothing
		Catch ex As Exception
			Throw
		End Try
	End Function

#End Region

#Region "全件入力"

	''' ---------------------------------------------
	''' <summary>
	''' 画面クリア（全件入力）
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub clearScreenAllEnt()
		Try
			If _FrmAllEnt.Rows Is Nothing OrElse _
				_FrmAllEnt.Rows.Count <= 0 Then
				Return
			End If
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return
			End If
			'画面クリア
			For Each row As clsRow In _FrmAllEnt.Rows
				For Each ctl As clsRowControl In _FrmAllEnt.RowControls
					If Not String.IsNullOrEmpty(ctl.ControlName) Then
						row.Control.Controls(ctl.ControlName).Text = String.Empty
					End If
				Next
			Next
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面データ設定（全件入力）
	''' </summary>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setDataToFormAllEnt()
		Try
			If _FrmAllEnt.Rows Is Nothing OrElse _
				_FrmAllEnt.Rows.Count <= 0 Then
				Return
			End If
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return
			End If

			Using db As New clsDB(clsSysMst.ctlConfigData),
				dt As New DataTable
				With db
					' 検索なし
					' マスタデータ取得SQL文作成
					Dim strOrder As String = String.Empty
					Dim strItem As String = getItemStringAllEnt()
					Dim strPrimaryKeyItem As String = getOrderStringAllEnt()

					If Not String.IsNullOrEmpty(strPrimaryKeyItem) Then
						strOrder = String.Format(sqlMstMenteCom.sqlOrder, strPrimaryKeyItem)
					End If
					Dim strSql As String = String.Format(sqlMstMenteCom.sqlSelect, strItem, _FrmAllEnt.TableName, strOrder)

					.setSQLDa(strSql)
					.execQueryDa(dt)
				End With
				'RowHeaderの表示値設定
				For Each row As clsRow In _FrmAllEnt.Rows
					For Each ctl As clsRowControl In _FrmAllEnt.RowControls
						If ctl.RowHeader Then
							'RowHeaderの表示値設定
							row.Control.Controls(ctl.ControlName).Text = row.RowCaption
							Exit For
						End If
					Next
				Next
				'ControlHeader以外の値設定
				For Each drow As DataRow In dt.Rows
					For Each row As clsRow In _FrmAllEnt.Rows
						For Each ctl As clsRowControl In _FrmAllEnt.RowControls
							If Not ctl.RowHeader Then
								'RowHeaderでない項目の値設定
								If row.RowID = GetRowIDAllEnt(drow) Then
									'データテーブルの値設定
									row.Control.Controls(ctl.ControlName).Text = drow(ctl.ColumnName).ToString
								End If
							End If
						Next
					Next
				Next
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ツールチップ設定（全件入力）
	''' </summary>
	''' <param name="ttp"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub setToolTipsAllEnt(ByVal ttp As ToolTip)
		Try
			If _FrmAllEnt.Rows Is Nothing OrElse _
				_FrmAllEnt.Rows.Count <= 0 Then
				Return
			End If
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return
			End If
			ttp = New ToolTip()
			ttp.ShowAlways = True
			For Each row As clsRow In _FrmAllEnt.Rows
				For Each ctl As clsRowControl In _FrmAllEnt.RowControls
					If Not String.IsNullOrEmpty(ctl.ToolTipText) AndAlso _
						Not String.IsNullOrEmpty(ctl.ControlName) Then
						ttp.SetToolTip(row.Control.Controls(ctl.ControlName), ctl.ToolTipText)
					End If
				Next
			Next
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 必須チェック（全件入力）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function isRequiredAllEnt() As Boolean
		Try
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return False
			End If

			If Not _FrmAllEnt.ValidateChildren() Then
				Return False
			End If
			For Each row As clsRow In _FrmAllEnt.Rows
				For Each ctl As clsRowControl In _FrmAllEnt.RowControls
					If ctl.Required Then
						If String.IsNullOrEmpty(GetValueAllEnt(row, ctl.ControlName)) Then
							DirectCast(_FrmAllEnt, frmBase).addErrListParent("E0001", row.Control.Name, ctl.ControlName, ctl.Caption, Nothing)
						End If
					End If
				Next
			Next
			If DirectCast(_FrmAllEnt, frmBase).getErrCount() > 0 Then
				Return False
			Else
				Return True				'エラーがない場合、正常終了
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' データ更新処理（全件入力）
	''' </summary>
	''' <param name="db"></param>
	''' <param name="bCreateNotEntered"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub modifyDataAllEnt(ByVal db As clsDB, ByVal bCreateNotEntered As Boolean)
		Try
			'データ全件削除
			deleteAllDataAllEnt(db)
			'データ全件登録
			insertAllDataAllEnt(db, bCreateNotEntered)
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 全件削除処理（全件入力）
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/05/21 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub deleteAllDataAllEnt(ByVal db As clsDB)
		Try
			db.setSQL(String.Format(sqlMstMenteCom.sqlDeleteAll, _FrmAllEnt.TableName))
			db.execNonQuery(False)
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 全件追加処理（全件入力）
	''' </summary>
	''' <param name="db"></param>
	''' <remarks>
	''' 2013/05/21 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub insertAllDataAllEnt(ByVal db As clsDB, ByVal bCreateNotEntered As Boolean)
		Try
			Dim strItem As String = getItemStringAllEnt() & sqlMstMenteCom.sqlFIXED_ITEM
			Dim strValue As String = getInsertItemStringAllEnt()
			Dim strSql As String = String.Format(sqlMstMenteCom.sqlInsert, _FrmAllEnt.TableName, strItem, strValue)
			For Each row As clsRow In _FrmAllEnt.Rows
				If bCreateNotEntered Then
					'未入力列を追加
					db.setSQL(strSql)
					setSqlParamAllEnt(db, row)
					db.execNonQuery(False)
				ElseIf isEnteredAllEnt(row) Then
					'入力列のみ追加
					db.setSQL(strSql)
					setSqlParamAllEnt(db, row)
					db.execNonQuery(False)
				End If
			Next
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try

	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－項目名文字列作成（SELECT,INSERT）（全件入力）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getItemStringAllEnt() As String
		Dim strRet As String = String.Empty
		Try
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count < 0 Then
				Return Nothing
			End If

			For Each col As clsRowControl In _FrmAllEnt.RowControls
				strRet &= col.ColumnName & ","
			Next
			strRet = strRet.Substring(0, strRet.Length - 1)

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－ＯＲＤＥＲ文字列作成（全件入力）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getOrderStringAllEnt() As String
		Dim strRet As String = String.Empty
		Try
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return Nothing
			End If

			For Each col As clsRowControl In _FrmAllEnt.RowControls
				If col.PrimaryKey Then
					strRet &= col.ColumnName & ","
				End If
			Next
			If strRet.Length > 0 Then
				strRet = strRet.Substring(0, strRet.Length - 1)
			End If

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' RowHeaderのRowControlのテーブル項目名より値取得
	''' </summary>
	''' <param name="drow"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2013/05/20 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function GetRowIDAllEnt(ByVal drow As DataRow) As String
		Try
			Dim strRet As String = Nothing
			For Each ctl As clsRowControl In _FrmAllEnt.RowControls
				'RowHeaderか？
				If ctl.RowHeader Then
					strRet = drow(ctl.ColumnName).ToString()
					Exit For
				End If
			Next

			Return strRet
		Catch ex As Exception
			Throw
		End Try
	End Function

	 ''' ---------------------------------------------
	 ''' <summary>
	 ''' コントロールの値取得（全件入力）
	 ''' </summary>
	 ''' <param name="row"></param>
	 ''' <param name="name"></param>
	 ''' <returns></returns>
	 ''' <remarks>
	 ''' 2013/05/21 新規作成　ID)平井<BR/>
	 ''' </remarks>
	 ''' ---------------------------------------------
	Private Function GetValueAllEnt(ByVal row As clsRow, ByVal name As String) As String
		Try
			If TypeOf row.Control.Controls(name) Is BT_Mask Then
				Return DirectCast(row.Control.Controls(name), BT_Mask).Text.Trim
			Else
				Return row.Control.Controls(name).Text
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－項目名文字列作成（INSERT VALUE）（全件入力）
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2013/05/21 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getInsertItemStringAllEnt() As String
		Dim strRet As String = String.Empty
		Try
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return Nothing
			End If

			For Each ctl As clsRowControl In _FrmAllEnt.RowControls
				If ctl.UpdateItem Then
					strRet &= sqlMstMenteCom.prmItem & ctl.ColumnName & ","
				End If
			Next
			strRet &= sqlMstMenteCom.sqlFIXED_PARAM

			Return strRet

		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ－パラメータ作成（全件入力）
	''' </summary>
	''' <param name="db"></param>
	''' <param name="row"></param>
	''' <remarks>
	''' 2013/04/25 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParamAllEnt(ByVal db As clsDB, ByVal row As clsRow)
		Try
			If _FrmAllEnt.RowControls Is Nothing OrElse _
				_FrmAllEnt.RowControls.Count <= 0 Then
				Return
			End If

			Dim strParam As String
			With db
				For Each ctl As clsRowControl In _FrmAllEnt.RowControls
					If ctl.UpdateItem Then
						strParam = sqlMstMenteCom.prmItem & ctl.ColumnName
						.setParam(strParam, CType(ctl.DbType, Integer))
						If ctl.RowHeader Then
							' RowHeaderの場合はRowIDを設定
							.setVal(strParam, row.RowID)
						Else
							.setVal(strParam, GetValue(row.Control.Controls(ctl.ControlName)))
						End If
					End If
				Next
				' 固定項目
				.setParam(sqlMstMenteCom.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMstMenteCom.prmLASTUPDUSER_CD, CType(_Frm, frmBase)._userID)
				.setParam(sqlMstMenteCom.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMstMenteCom.prmLASTUPD_DT, Now)
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Row内コントロールでRowHeader以外のUpdateItemの入力有無を返す。
	''' </summary>
	''' <param name="row"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2013/05/21 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function isEnteredAllEnt(ByVal row As clsRow) As Boolean
		Try
			For Each ctl As clsRowControl In _FrmAllEnt.RowControls
				' RowHeader以外　かつ　更新項目
				If Not ctl.RowHeader AndAlso
					ctl.UpdateItem Then
					If Not String.IsNullOrEmpty(row.Control.Controls(ctl.ControlName).Text) Then
						' 入力あり
						Return True
					End If
				End If
			Next
			' 入力なし
			Return False
		Catch ex As Exception
			Throw
		End Try
	End Function

#End Region

#End Region

End Class