﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 治療処置情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_CARE
	Implements IDisposable

#Region "変数"

	' 処置一覧並び替え設定
	Private strOrderBy As String = sqlMTI_CARE.sqlOrder_By_Default

#End Region

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pSort">処置一覧並び替え設定</param>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pSort As clsConst.Enum_SortCare)
		Me.New()
		Select Case pSort
			Case clsConst.Enum_SortCare.NoSort
				strOrderBy = sqlMTI_CARE.sqlOrder_By_NoSort
			Case clsConst.Enum_SortCare.Sort
				strOrderBy = sqlMTI_CARE.sqlOrder_By_Sort
			Case clsConst.Enum_SortCare.SortDivDt
				strOrderBy = sqlMTI_CARE.sqlOrder_By_SortDivDt
			Case Else
		End Select
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pCareSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' SQL文の取得
	''' </summary>
	''' <param name="strSQL">SQL文</param>
	''' <returns>ORDER BY句を変更したSQL文</returns>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getSQL(ByVal strSQL As String) As String
		Try
			Return strSQL.Replace(sqlMTI_CARE.strORDER_BY, strOrderBy)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より治療処置情報クラスを作成
	''' </summary>
	''' <param name="pRow">治療処置情報 DataRow</param>
	''' <returns>治療処置情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareRecFromDataRow(ByVal pRow As DataRow) As datMTI_CARE_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "DataRow より治療処置情報クラスを作成 Start")
		Dim retDat As datMTI_CARE_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_CARE_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より治療処置情報＋名称クラスを作成
	''' </summary>
	''' <param name="pRow">治療処置情報 DataRow</param>
	''' <returns>治療処置情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusRecFromDataRow(ByVal pRow As DataRow) As datMTI_CARE_PLUS_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "DataRow より治療処置情報＋名称クラスを作成 Start")
		Dim retDat As datMTI_CARE_PLUS_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_CARE_PLUS_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Patient))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_CARE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報（ArrayList内にdatMTI_CARE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Ch))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As datMTI_CARE_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As datMTI_CARE_OneRec
		Dim retDat As datMTI_CARE_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_CARE_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCareOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCareOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_OneRec))

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Patient))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_CARE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報＋名称（ArrayList内にdatMTI_CARE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Ch))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Plus_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As datMTI_CARE_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As datMTI_CARE_PLUS_OneRec
		Dim retDat As datMTI_CARE_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_CARE.sqlSelCare_Plus_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_CARE_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_CARE_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCarePlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <returns>治療処置情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCarePlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_CARE.sqlSelCare_Plus_OneRec))

			db.setParamDa(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setValDa(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CARE.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の治療処置情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCarePatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "１患者分の治療処置情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CARE.sqlDelCare_Patient)	'DELETE文設定
				db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の治療処置情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCareHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "１入退院分の治療処置情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CARE.sqlDelCare_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の治療処置情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCareCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "１科歴分の治療処置情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CARE.sqlDelCare_Ch)	'DELETE文設定
				db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCareSerialNo">治療処置連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCareOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCareSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "治療処置情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pCareSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CARE.sqlDelCare_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
				db.setVal(sqlMTI_CARE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CARE.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCareRec">治療処置情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pCareRec As datMTI_CARE_OneRec) As Integer
		Try
			Return execInsCareOneRec(db, pCareRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">治療処置情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pCareRec As datMTI_CARE_OneRec = Nothing
		Try
			Return execInsCareOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pCareRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">治療処置情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pCareRec As datMTI_CARE_OneRec = Nothing
		Try
			pCareRec = getCareRecFromDataRow(pRow)
			Return execInsCareOneRec(db, pCareRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCareRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCarePlusRec">治療処置情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pCarePlusRec As datMTI_CARE_PLUS_OneRec) As Integer
		Try
			Return execInsCareOneRec(db, pCarePlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCarePlusRec">治療処置情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pCarePlusRec As datMTI_CARE_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pCareRec As datMTI_CARE_OneRec = Nothing
		Try
			If pCarePlusRec IsNot Nothing Then
				pCareRec = pCarePlusRec.OrgCopy
			End If
			Return execInsCareOneRec(db, pCareRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCareRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 治療処置情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCareRec">治療処置情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCareOneRec(ByVal db As clsDB, ByVal pCareRec As datMTI_CARE_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "治療処置情報アクセスクラス", "治療処置情報１データを追加 Start")
		Try
			If pCareRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_CARE.sqlInsCare_OneRec)
			' 患者番号
			db.setParam(sqlMTI_CARE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmPATIENT_NO, pCareRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_CARE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CARE.prmHSP_HISTORY_NO, pCareRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_CARE.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CARE.prmCH_NO, pCareRec.CH_NO, False)
			' 治療処置連番
			db.setParam(sqlMTI_CARE.prmCARE_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CARE.prmCARE_SERIAL_NO, pCareRec.CARE_SERIAL_NO, False)
			' 治療処置区分コード
			db.setParam(sqlMTI_CARE.prmCARE_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmCARE_DIV, pCareRec.CARE_DIV)
			' 治療処置名
			db.setParam(sqlMTI_CARE.prmCARE_NM, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmCARE_NM, pCareRec.CARE_NM)
			' 実施日
			db.setParam(sqlMTI_CARE.prmCARE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CARE.prmCARE_DT, pCareRec.CARE_DT)
			' 補助区分コード
			db.setParam(sqlMTI_CARE.prmASST_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmASST_DIV, pCareRec.ASST_DIV)
			' 備考１
			db.setParam(sqlMTI_CARE.prmREMARKS1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmREMARKS1, pCareRec.REMARKS1)
			' 備考２
			db.setParam(sqlMTI_CARE.prmREMARKS2, clsDB.Enum_dbType.dbNumeric)
			If pCareRec.REMARKS2.HasValue Then
				db.setVal(sqlMTI_CARE.prmREMARKS2, pCareRec.REMARKS2.Value, False)
			Else
				db.setVal(sqlMTI_CARE.prmREMARKS2, 0)
			End If
			' ＩＣＤ９ＣＭコード
			db.setParam(sqlMTI_CARE.prmICD9CM_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmICD9CM_CD, pCareRec.ICD9CM_CD)
			' 大分類コード
			db.setParam(sqlMTI_CARE.prmL_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmL_GRP_CD, pCareRec.L_GRP_CD)
			' 中分類コード
			db.setParam(sqlMTI_CARE.prmM_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmM_GRP_CD, pCareRec.M_GRP_CD)
			' ３桁分類コード
			db.setParam(sqlMTI_CARE.prmDIGS3_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmDIGS3_GRP_CD, pCareRec.DIGS3_GRP_CD)
			' 管理記号
			db.setParam(sqlMTI_CARE.prmMNG_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmMNG_DIV, pCareRec.MNG_DIV)
			' 管理番号
			db.setParam(sqlMTI_CARE.prmMNG_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CARE.prmMNG_NO, pCareRec.MNG_NO, False)
			' 点数表コード
			db.setParam(sqlMTI_CARE.prmSCORE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmSCORE_CD, pCareRec.SCORE_CD)
			' 院内手術コード
			db.setParam(sqlMTI_CARE.prmHSP_OPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CARE.prmHSP_OPE_CD, pCareRec.HSP_OPE_CD)
			' データ取込日
			db.setParam(sqlMTI_CARE.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CARE.prmDATA_CAPTURE_DT, pCareRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_CARE.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CARE.prmNEW_REG_DT, pCareRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_CARE.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pCareRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_CARE.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_CARE.prmLASTUPDUSER_CD, pCareRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_CARE.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pCareRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_CARE.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_CARE.prmLASTUPD_DT, pCareRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
