﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 分娩情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_CB
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より分娩情報クラスを作成
	''' </summary>
	''' <param name="pRow">分娩情報 DataRow</param>
	''' <returns>分娩情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getCbRecFromDataRow(ByVal pRow As DataRow) As datMTI_CB_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩情報アクセスクラス", "DataRow より分娩情報クラスを作成 Start")
		Dim retDat As datMTI_CB_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_CB_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

'(A) STR V4-12031-000 213 2012/06/07 ID)平井 DPC2012対応
	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の分娩情報（ArrayList内にdatMTI_CB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の分娩情報（ArrayList内にdatMTI_CB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB.sqlSelCb_Patient)	'SELECT文設定
			db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_CB_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB.sqlSelCb_Patient)	'SELECT文設定

			db.setParamDa(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の分娩情報（ArrayList内にdatMTI_CB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の分娩情報（ArrayList内にdatMTI_CB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB.sqlSelCb_Hsp)	'SELECT文設定
			db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB.sqlSelCb_Hsp)	'SELECT文設定

			db.setParamDa(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function
'(A) END V4-12031-000 213 2012/06/07 ID)平井 DPC2012対応

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>分娩情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_CB_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbOneRec(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>分娩情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_CB_OneRec
		Dim retDat As datMTI_CB_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB.sqlSelCb_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_CB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_OneRec), arData)	'値取得
			If iRet > 0 Then										'レコードあり
				retDat = DirectCast(arData(0), datMTI_CB_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>分娩情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB.sqlSelCb_OneRec)	'SELECT文設定

			db.setParamDa(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_CB.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩情報アクセスクラス", "１患者分の分娩情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB.sqlDelCb_Patient)	'DELETE文設定
				db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩情報アクセスクラス", "１入退院分の分娩情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB.sqlDelCb_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩情報アクセスクラス", "分娩情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB.sqlDelCb_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_CB.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CB.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbRec">分娩情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbOneRec(ByVal db As clsDB, ByVal pCbRec As datMTI_CB_OneRec) As Integer
		Try
			Return execInsCbOneRec(db, pCbRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pCbRec As datMTI_CB_OneRec = Nothing
		Try
			Return execInsCbOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pCbRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pCbRec As datMTI_CB_OneRec = Nothing
		Try
			pCbRec = getCbRecFromDataRow(pRow)
			Return execInsCbOneRec(db, pCbRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCbRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbRec">分娩情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbOneRec(ByVal db As clsDB, ByVal pCbRec As datMTI_CB_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩情報アクセスクラス", "分娩情報１データを追加 Start")
		Try
			If pCbRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_CB.sqlInsCb_OneRec)
			' 患者番号
			db.setParam(sqlMTI_CB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmPATIENT_NO, pCbRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_CB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmHSP_HISTORY_NO, pCbRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_CB.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCH_NO, pCbRec.CH_NO, False)
			' 分娩日
			db.setParam(sqlMTI_CB.prmCB_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CB.prmCB_DT, pCbRec.CB_DT)
			' 分娩時年齢
			db.setParam(sqlMTI_CB.prmCB_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCB_AGE, pCbRec.CB_AGE, False)
			' 分娩時月齢
			db.setParam(sqlMTI_CB.prmCB_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCB_MONTH_AGE, pCbRec.CB_MONTH_AGE, False)
			' 在胎週数
			db.setParam(sqlMTI_CB.prmGESTATIONAL_WEEK_COUNT, clsDB.Enum_dbType.dbInt)
			If pCbRec.GESTATIONAL_WEEK_COUNT.HasValue Then
				db.setVal(sqlMTI_CB.prmGESTATIONAL_WEEK_COUNT, pCbRec.GESTATIONAL_WEEK_COUNT.Value, False)
			Else
				db.setVal(sqlMTI_CB.prmGESTATIONAL_WEEK_COUNT, 0)
			End If
			' 在胎日数
			db.setParam(sqlMTI_CB.prmGESTATIONAL_DAY_COUNT, clsDB.Enum_dbType.dbInt)
			If pCbRec.GESTATIONAL_DAY_COUNT.HasValue Then
				db.setVal(sqlMTI_CB.prmGESTATIONAL_DAY_COUNT, pCbRec.GESTATIONAL_DAY_COUNT.Value, False)
			Else
				db.setVal(sqlMTI_CB.prmGESTATIONAL_DAY_COUNT, 0)
			End If
			' 児数
			db.setParam(sqlMTI_CB.prmCHD_COUNT, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCHD_COUNT, pCbRec.CHD_COUNT, False)
			' 分娩区分コード１
			db.setParam(sqlMTI_CB.prmCB_DIV1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmCB_DIV1, pCbRec.CB_DIV1)
			' 分娩区分コード２
			db.setParam(sqlMTI_CB.prmCB_DIV2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmCB_DIV2, pCbRec.CB_DIV2)
			' 分娩区分コード３
			db.setParam(sqlMTI_CB.prmCB_DIV3, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmCB_DIV3, pCbRec.CB_DIV3)
			' 分娩区分コード４
			db.setParam(sqlMTI_CB.prmCB_DIV4, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmCB_DIV4, pCbRec.CB_DIV4)
			' 早産
			db.setParam(sqlMTI_CB.prmPREMATURE_BIRTH, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmPREMATURE_BIRTH, pCbRec.PREMATURE_BIRTH, False)
			' 流産
			db.setParam(sqlMTI_CB.prmMISCARRIAGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmMISCARRIAGE, pCbRec.MISCARRIAGE, False)
			' 出血量
			db.setParam(sqlMTI_CB.prmBLEEDING_VOLUME, clsDB.Enum_dbType.dbInt)
			If pCbRec.BLEEDING_VOLUME.HasValue Then
				db.setVal(sqlMTI_CB.prmBLEEDING_VOLUME, pCbRec.BLEEDING_VOLUME.Value, False)
			Else
				db.setVal(sqlMTI_CB.prmBLEEDING_VOLUME, 0)
			End If
			' 帝王切開有無コード
			db.setParam(sqlMTI_CB.prmCAESAREAN_OPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmCAESAREAN_OPE_CD, pCbRec.CAESAREAN_OPE_CD)
			' 分娩チェック項目１
			db.setParam(sqlMTI_CB.prmCB_CHK1, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCB_CHK1, pCbRec.CB_CHK1, False)
			' 分娩チェック項目２
			db.setParam(sqlMTI_CB.prmCB_CHK2, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCB_CHK2, pCbRec.CB_CHK2, False)
			' 分娩チェック項目３
			db.setParam(sqlMTI_CB.prmCB_CHK3, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB.prmCB_CHK3, pCbRec.CB_CHK3, False)
			' 備考
			db.setParam(sqlMTI_CB.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB.prmREMARKS, pCbRec.REMARKS)
			' データ取込日
			db.setParam(sqlMTI_CB.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CB.prmDATA_CAPTURE_DT, pCbRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_CB.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CB.prmNEW_REG_DT, pCbRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_CB.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pCbRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_CB.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_CB.prmLASTUPDUSER_CD, pCbRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_CB.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pCbRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_CB.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_CB.prmLASTUPD_DT, pCbRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
