﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 救命救急情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_EMERGENCY
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pEmergencySerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEnteringDt">入室日</param>
	''' <param name="pLeavingDt">退室日</param>
	''' <param name="pSevereCd">重症コード</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEnteringDt As Date, ByVal pLeavingDt As Date, ByVal pSevereCd As String) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso Not (pEnteringDt.Equals(Nothing) OrElse pLeavingDt.Equals(Nothing) OrElse String.IsNullOrEmpty(pSevereCd))
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より救命救急情報クラスを作成
	''' </summary>
	''' <param name="pRow">救命救急情報 DataRow</param>
	''' <returns>救命救急情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getEmergencyRecFromDataRow(ByVal pRow As DataRow) As datMTI_EMERGENCY_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "DataRow より救命救急情報クラスを作成 Start")
		Dim retDat As datMTI_EMERGENCY_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_EMERGENCY_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報（ArrayList内にdatMTI_EMERGENCY_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報（ArrayList内にdatMTI_EMERGENCY_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelEmergency_Ch)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_EMERGENCY.sqlSelEmergency_Ch)

			db.setParamDa(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As datMTI_EMERGENCY_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As datMTI_EMERGENCY_OneRec
		Dim retDat As datMTI_EMERGENCY_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelEmergency_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'救命救急連番
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencySerialNo, False)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_EMERGENCY_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_EMERGENCY.sqlSelEmergency_OneRec)

			db.setParamDa(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'救命救急連番
			db.setValDa(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencySerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報＋名称（ArrayList内にdatMTI_EMERGENCY_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyPlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報＋名称（ArrayList内にdatMTI_EMERGENCY_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelEmergency_Plus_Ch)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyPlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の救命救急情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_EMERGENCY.sqlSelEmergency_Plus_Ch)

			db.setParamDa(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As datMTI_EMERGENCY_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyPlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As datMTI_EMERGENCY_PLUS_OneRec
		Dim retDat As datMTI_EMERGENCY_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelEmergency_Plus_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'救命救急連番
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencySerialNo, False)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_EMERGENCY_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getEmergencyPlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <returns>救命救急情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getEmergencyPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_EMERGENCY.sqlSelEmergency_Plus_OneRec)

			db.setParamDa(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'救命救急連番
			db.setValDa(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencySerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴中の救命救急連番の最大値を取得します
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>救命救急連番の最大値</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMaxSerialNoCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Integer
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMaxSerialNoCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴中の救命救急連番の最大値を取得します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>救命救急連番の最大値</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMaxSerialNoCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Integer
		Dim retVal As Integer = 0
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return 0
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelMaxSerialNo_Ch)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_KeyRec), arData)	'値取得
			If iRet > 0 Then	'レコードあり
				retVal = DirectCast(arData(0), datMTI_EMERGENCY_KeyRec).EMERGENCY_SERIAL_NO
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retVal
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 病棟情報の項目よりキー項目の存在を確認します
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEnteringDt">入室日</param>
	''' <param name="pLeavingDt">退室日</param>
	''' <param name="pSevereCd">重症コード</param>
	''' <returns>キー項目の存在の有無</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function isExistKeyFromWard(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEnteringDt As Date, ByVal pLeavingDt As Date, ByVal pSevereCd As String) As Boolean
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return isExistKeyFromWard(db, pPatientNo, pHspHistoryNo, pChNo, pEnteringDt, pLeavingDt, pSevereCd)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 病棟情報の項目よりキー項目の存在を確認します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>キー項目の存在の有無</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function isExistKeyFromWard(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEnteringDt As Date, ByVal pLeavingDt As Date, ByVal pSevereCd As String) As Boolean
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pEnteringDt, pLeavingDt, pSevereCd) Then
				' 存在していることとする
				Return True
			End If

			db.setSQL(sqlMTI_EMERGENCY.sqlSelEmergency_Key_From_Ward)	'SELECT文設定
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_DT, clsDB.Enum_dbType.dbDateTime)		'入室日
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_DT, clsDB.Enum_dbType.dbDateTime)		'退室日
			db.setParam(sqlMTI_EMERGENCY.prmSEVERE_CD, clsDB.Enum_dbType.dbNVarChar)			'重症コード
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_DT, pEnteringDt)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_DT, pLeavingDt)
			db.setVal(sqlMTI_EMERGENCY.prmSEVERE_CD, pSevereCd)
			iRet = db.execQuery(GetType(datMTI_EMERGENCY_KeyRec), arData)	'値取得
			If iRet > 0 Then	'レコードあり
				Return True
			Else
				Return False
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の救命救急情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelEmergencyPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "１患者分の救命救急情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_EMERGENCY.sqlDelEmergency_Patient)	'DELETE文設定
				db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
				db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の救命救急情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelEmergencyHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "１入退院分の救命救急情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_EMERGENCY.sqlDelEmergency_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
				db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
				db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の救命救急情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelEmergencyCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "１科歴分の救命救急情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_EMERGENCY.sqlDelEmergency_Ch)	'DELETE文設定
				db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
				db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
				db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
				db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pEmergencySerialNo">救命救急連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelEmergencyOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pEmergencySerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "救命救急情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pEmergencySerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_EMERGENCY.sqlDelEmergency_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
				db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
				db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
				db.setParam(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'救命救急連番
				db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencySerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pEmergencyRec">救命救急情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsEmergencyOneRec(ByVal db As clsDB, ByVal pEmergencyRec As datMTI_EMERGENCY_OneRec) As Integer
		Try
			Return execInsEmergencyOneRec(db, pEmergencyRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">救命救急情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsEmergencyOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pEmergencyRec As datMTI_EMERGENCY_OneRec = Nothing
		Try
			Return execInsEmergencyOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pEmergencyRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">救命救急情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsEmergencyOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pEmergencyRec As datMTI_EMERGENCY_OneRec = Nothing
		Try
			pEmergencyRec = getEmergencyRecFromDataRow(pRow)
			Return execInsEmergencyOneRec(db, pEmergencyRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pEmergencyRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 救命救急情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pEmergencyRec">救命救急情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsEmergencyOneRec(ByVal db As clsDB, ByVal pEmergencyRec As datMTI_EMERGENCY_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "救命救急情報アクセスクラス", "救命救急情報１データを追加 Start")
		Try
			If pEmergencyRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_EMERGENCY.sqlInsEmergency_OneRec)
			' 患者番号
			db.setParam(sqlMTI_EMERGENCY.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmPATIENT_NO, pEmergencyRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmHSP_HISTORY_NO, pEmergencyRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_EMERGENCY.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmCH_NO, pEmergencyRec.CH_NO, False)
			' 救命救急連番
			db.setParam(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmEMERGENCY_SERIAL_NO, pEmergencyRec.EMERGENCY_SERIAL_NO, False)
			' 入法コード
			db.setParam(sqlMTI_EMERGENCY.prmIN_METHOD_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmIN_METHOD_CD, pEmergencyRec.IN_METHOD_CD)
			' 出法コード
			db.setParam(sqlMTI_EMERGENCY.prmOUT_METHOD_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmOUT_METHOD_CD, pEmergencyRec.OUT_METHOD_CD)
			' 入室日
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_DT, pEmergencyRec.ENTERING_DT)
			' 入室時刻
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_TIME, pEmergencyRec.ENTERING_TIME)
			' 退室日
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_DT, pEmergencyRec.LEAVING_DT)
			' 退室時刻
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_TIME, pEmergencyRec.LEAVING_TIME)
			' 入室時年齢
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_AGE, pEmergencyRec.ENTERING_AGE, False)
			' 入室時月齢
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_MONTH_AGE, pEmergencyRec.ENTERING_MONTH_AGE, False)
			' 入室時日齢
			db.setParam(sqlMTI_EMERGENCY.prmENTERING_DAY_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmENTERING_DAY_AGE, pEmergencyRec.ENTERING_DAY_AGE, False)
			' 退室時年齢
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_AGE, pEmergencyRec.LEAVING_AGE, False)
			' 退室時月齢
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_MONTH_AGE, pEmergencyRec.LEAVING_MONTH_AGE, False)
			' 退室時日齢
			db.setParam(sqlMTI_EMERGENCY.prmLEAVING_DAY_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmLEAVING_DAY_AGE, pEmergencyRec.LEAVING_DAY_AGE, False)
			' 在室日数
			db.setParam(sqlMTI_EMERGENCY.prmIN_ROOM_DAYS, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_EMERGENCY.prmIN_ROOM_DAYS, pEmergencyRec.IN_ROOM_DAYS, False)
			' 重症コード
			db.setParam(sqlMTI_EMERGENCY.prmSEVERE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmSEVERE_CD, pEmergencyRec.SEVERE_CD)
			' 救命所要時間
			db.setParam(sqlMTI_EMERGENCY.prmMED_REQUIRED_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_EMERGENCY.prmMED_REQUIRED_TIME, pEmergencyRec.MED_REQUIRED_TIME)
			' 更新者コード
			db.setParam(sqlMTI_EMERGENCY.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pEmergencyRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_EMERGENCY.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_EMERGENCY.prmLASTUPDUSER_CD, pEmergencyRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_EMERGENCY.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pEmergencyRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_EMERGENCY.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_EMERGENCY.prmLASTUPD_DT, pEmergencyRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
