﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 手術医師情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_OPE_DOCTOR
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pOpeSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) AndAlso (pOpeDoctorSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より手術医師情報クラスを作成
	''' </summary>
	''' <param name="pRow">手術医師情報 DataRow</param>
	''' <returns>手術医師情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorRecFromDataRow(ByVal pRow As DataRow) As datMTI_OPE_DOCTOR_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "DataRow より手術医師情報クラスを作成 Start")
		Dim retDat As datMTI_OPE_DOCTOR_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_OPE_DOCTOR_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より手術医師情報＋名称クラスを作成
	''' </summary>
	''' <param name="pRow">手術医師情報 DataRow</param>
	''' <returns>手術医師情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusRecFromDataRow(ByVal pRow As DataRow) As datMTI_OPE_DOCTOR_PLUS_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "DataRow より手術医師情報＋名称クラスを作成 Start")
		Dim retDat As datMTI_OPE_DOCTOR_PLUS_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_OPE_DOCTOR_PLUS_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報（ArrayList内にdatMTI_OPE_DOCTOR_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報（ArrayList内にdatMTI_OPE_DOCTOR_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Ch)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Ch)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報（ArrayList内にdatMTI_OPE_DOCTOR_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorSerial(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorSerial(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報（ArrayList内にdatMTI_OPE_DOCTOR_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorSerial(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Serial)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorSerialDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorSerialDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorSerialDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Serial)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'手術連番
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As datMTI_OPE_DOCTOR_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As datMTI_OPE_DOCTOR_OneRec
		Dim retDat As datMTI_OPE_DOCTOR_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術医師連番
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_OPE_DOCTOR_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_OneRec)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術医師連番
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報＋名称（ArrayList内にdatMTI_OPE_DOCTOR_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報＋名称（ArrayList内にdatMTI_OPE_DOCTOR_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_Ch)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_Ch)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報＋名称（ArrayList内にdatMTI_OPE_DOCTOR_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusSerial(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusSerial(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報＋名称（ArrayList内にdatMTI_OPE_DOCTOR_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusSerial(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_Serial)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusSerialDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusSerialDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>１手術分の手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusSerialDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_Serial)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'手術連番
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As datMTI_OPE_DOCTOR_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As datMTI_OPE_DOCTOR_PLUS_OneRec
		Dim retDat As datMTI_OPE_DOCTOR_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術医師連番
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_DOCTOR_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_OPE_DOCTOR_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeDoctorPlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <returns>手術医師情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeDoctorPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OPE_DOCTOR.sqlSelOpeDoctor_Plus_OneRec)

			db.setParamDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)			'入退院歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
			db.setParamDa(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術医師連番
			db.setValDa(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			db.setValDa(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術医師情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeDoctorPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "１患者分の手術医師情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE_DOCTOR.sqlDelOpeDoctor_Patient)	'DELETE文設定
				db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術医師情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeDoctorHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "１入退院分の手術医師情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE_DOCTOR.sqlDelOpeDoctor_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術医師情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeDoctorCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "１科歴分の手術医師情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE_DOCTOR.sqlDelOpeDoctor_Ch)	'DELETE文設定
				db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
				db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １手術分の手術医師情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeDoctorSerial(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "１手術分の手術医師情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE_DOCTOR.sqlDelOpeDoctor_Serial)	'DELETE文設定
				db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
				db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <param name="pOpeDoctorSerialNo">手術医師連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeDoctorOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer, ByVal pOpeDoctorSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "手術医師情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo, pOpeDoctorSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE_DOCTOR.sqlDelOpeDoctor_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
				db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)			'手術連番
				db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術医師連番
				db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeSerialNo, False)
				db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeDoctorRec">手術医師情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pOpeDoctorRec As datMTI_OPE_DOCTOR_OneRec) As Integer
		Try
			Return execInsOpeDoctorOneRec(db, pOpeDoctorRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">手術医師情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pOpeDoctorRec As datMTI_OPE_DOCTOR_OneRec = Nothing
		Try
			Return execInsOpeDoctorOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pOpeDoctorRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">手術医師情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pOpeDoctorRec As datMTI_OPE_DOCTOR_OneRec = Nothing
		Try
			pOpeDoctorRec = getOpeDoctorRecFromDataRow(pRow)
			Return execInsOpeDoctorOneRec(db, pOpeDoctorRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pOpeDoctorRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeDoctorPlusRec">手術医師情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pOpeDoctorPlusRec As datMTI_OPE_DOCTOR_PLUS_OneRec) As Integer
		Try
			Return execInsOpeDoctorOneRec(db, pOpeDoctorPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeDoctorPlusRec">手術医師情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pOpeDoctorPlusRec As datMTI_OPE_DOCTOR_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pOpeDoctorRec As datMTI_OPE_DOCTOR_OneRec = Nothing
		Try
			If pOpeDoctorPlusRec IsNot Nothing Then
				pOpeDoctorRec = pOpeDoctorPlusRec.OrgCopy
			End If
			Return execInsOpeDoctorOneRec(db, pOpeDoctorRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pOpeDoctorRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術医師情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeDoctorRec">手術医師情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeDoctorOneRec(ByVal db As clsDB, ByVal pOpeDoctorRec As datMTI_OPE_DOCTOR_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術医師情報アクセスクラス", "手術医師情報１データを追加 Start")
		Try
			If pOpeDoctorRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_OPE_DOCTOR.sqlInsOpeDoctor_OneRec)
			' 患者番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE_DOCTOR.prmPATIENT_NO, pOpeDoctorRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE_DOCTOR.prmHSP_HISTORY_NO, pOpeDoctorRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_OPE_DOCTOR.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE_DOCTOR.prmCH_NO, pOpeDoctorRec.CH_NO, False)
			' 手術連番
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_SERIAL_NO, pOpeDoctorRec.OPE_SERIAL_NO, False)
			' 手術医師連番
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_SERIAL_NO, pOpeDoctorRec.OPE_DOCTOR_SERIAL_NO, False)
			' 手術医師区分コード
			db.setParam(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE_DOCTOR.prmOPE_DOCTOR_DIV, pOpeDoctorRec.OPE_DOCTOR_DIV)
			' 医師コード
			db.setParam(sqlMTI_OPE_DOCTOR.prmDOCTOR_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE_DOCTOR.prmDOCTOR_CD, pOpeDoctorRec.DOCTOR_CD)
			' 更新者コード
			db.setParam(sqlMTI_OPE_DOCTOR.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pOpeDoctorRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_OPE_DOCTOR.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_OPE_DOCTOR.prmLASTUPDUSER_CD, pOpeDoctorRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_OPE_DOCTOR.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pOpeDoctorRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_OPE_DOCTOR.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_OPE_DOCTOR.prmLASTUPD_DT, pOpeDoctorRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
