﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' パス情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_PATH
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pPathSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow よりパス情報クラスを作成
	''' </summary>
	''' <param name="pRow">パス情報 DataRow</param>
	''' <returns>パス情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getPathRecFromDataRow(ByVal pRow As DataRow) As datMTI_PATH_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "DataRow よりパス情報クラスを作成 Start")
		Dim retDat As datMTI_PATH_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_PATH_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報（ArrayList内にdatMTI_PATH_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報（ArrayList内にdatMTI_PATH_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_PATH.sqlSelPath_Ch)	'SELECT文設定
			db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_PATH_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_PATH.sqlSelPath_Ch)	'SELECT文設定

			db.setParamDa(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As datMTI_PATH_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As datMTI_PATH_OneRec
		Dim retDat As datMTI_PATH_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_PATH.sqlSelPath_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParam(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'パス連番
			db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_PATH_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_PATH_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_PATH.sqlSelPath_OneRec)

			db.setParamDa(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'パス連番
			db.setValDa(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報＋名称（ArrayList内にdatMTI_PATH_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathPlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報＋名称（ArrayList内にdatMTI_PATH_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_PATH.sqlSelPath_Plus_Ch)	'SELECT文設定
			db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_PATH_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathPlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分のパス情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_PATH.sqlSelPath_Plus_Ch)	'SELECT文設定

			db.setParamDa(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As datMTI_PATH_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathPlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As datMTI_PATH_PLUS_OneRec
		Dim retDat As datMTI_PATH_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_PATH.sqlSelPath_Plus_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParam(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'パス連番
			db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_PATH_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_PATH_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getPathPlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <returns>パス情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getPathPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_PATH.sqlSelPath_Plus_OneRec)

			db.setParamDa(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'パス連番
			db.setValDa(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_PATH.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分のパス情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelPathPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "１患者分のパス情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_PATH.sqlDelPath_Patient)	'DELETE文設定
				db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分のパス情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelPathHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "１入退院分のパス情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_PATH.sqlDelPath_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分のパス情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelPathCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "１科歴分のパス情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_PATH.sqlDelPath_Ch)	'DELETE文設定
				db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pPathSerialNo">パス連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelPathOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pPathSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "パス情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pPathSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_PATH.sqlDelPath_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'パス連番
				db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_PATH.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPathRec">パス情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pPathRec As datMTI_PATH_OneRec) As Integer
		Try
			Return execInsPathOneRec(db, pPathRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">パス情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pPathRec As datMTI_PATH_OneRec = Nothing
		Try
			Return execInsPathOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pPathRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">パス情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pPathRec As datMTI_PATH_OneRec = Nothing
		Try
			pPathRec = getPathRecFromDataRow(pRow)
			Return execInsPathOneRec(db, pPathRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pPathRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPathPlusRec">パス情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pPathPlusRec As datMTI_PATH_PLUS_OneRec) As Integer
		Try
			Return execInsPathOneRec(db, pPathPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPathPlusRec">パス情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pPathPlusRec As datMTI_PATH_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pPathRec As datMTI_PATH_OneRec = Nothing
		Try
			If pPathPlusRec IsNot Nothing Then
				pPathRec = pPathPlusRec.OrgCopy
			End If
			Return execInsPathOneRec(db, pPathRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pPathRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パス情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPathRec">パス情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsPathOneRec(ByVal db As clsDB, ByVal pPathRec As datMTI_PATH_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "パス情報アクセスクラス", "パス情報１データを追加 Start")
		Try
			If pPathRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_PATH.sqlInsPath_OneRec)
			' 患者番号
			db.setParam(sqlMTI_PATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmPATIENT_NO, pPathRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_PATH.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_PATH.prmHSP_HISTORY_NO, pPathRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_PATH.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_PATH.prmCH_NO, pPathRec.CH_NO, False)
			' パス連番
			db.setParam(sqlMTI_PATH.prmPATH_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_PATH.prmPATH_SERIAL_NO, pPathRec.PATH_SERIAL_NO, False)
			' パスコード
			db.setParam(sqlMTI_PATH.prmPATH_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmPATH_CD, pPathRec.PATH_CD)
			' 開始日
			db.setParam(sqlMTI_PATH.prmSTART_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_PATH.prmSTART_DT, pPathRec.START_DT)
			' 終了日
			db.setParam(sqlMTI_PATH.prmEND_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_PATH.prmEND_DT, pPathRec.END_DT)
			' 医師コード
			db.setParam(sqlMTI_PATH.prmDOCTOR_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmDOCTOR_CD, pPathRec.DOCTOR_CD)
			' バリアンス日
			db.setParam(sqlMTI_PATH.prmVARIANCE_DAY, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_PATH.prmVARIANCE_DAY, pPathRec.VARIANCE_DAY)
			' 有無コード
			db.setParam(sqlMTI_PATH.prmCHK_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmCHK_CD, pPathRec.CHK_CD)
			' 種類コード
			db.setParam(sqlMTI_PATH.prmTYPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmTYPE_CD, pPathRec.TYPE_CD)
			' 理由コード１
			db.setParam(sqlMTI_PATH.prmREASON1_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmREASON1_CD, pPathRec.REASON1_CD)
			' 理由コード２
			db.setParam(sqlMTI_PATH.prmREASON2_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmREASON2_CD, pPathRec.REASON2_CD)
			' 理由コード３
			db.setParam(sqlMTI_PATH.prmREASON3_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmREASON3_CD, pPathRec.REASON3_CD)
			' 理由コード４
			db.setParam(sqlMTI_PATH.prmREASON4_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmREASON4_CD, pPathRec.REASON4_CD)
			' コメント
			db.setParam(sqlMTI_PATH.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_PATH.prmREMARKS, pPathRec.REMARKS)
			' 更新者コード
			db.setParam(sqlMTI_PATH.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pPathRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_PATH.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_PATH.prmLASTUPDUSER_CD, pPathRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_PATH.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pPathRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_PATH.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_PATH.prmLASTUPD_DT, pPathRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
