﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 検査情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_TEST
	Implements IDisposable

#Region "変数"

	' 検査一覧並び替え設定
	Private strOrderBy As String = sqlMTI_TEST.sqlOrder_By_Default

#End Region

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pSort">検査一覧並び替え設定</param>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pSort As clsConst.Enum_SortTest)
		Me.New()
		Select Case pSort
			Case clsConst.Enum_SortTest.NoSort
				strOrderBy = sqlMTI_TEST.sqlOrder_By_NoSort
			Case clsConst.Enum_SortTest.Sort
				strOrderBy = sqlMTI_TEST.sqlOrder_By_Sort
			Case clsConst.Enum_SortTest.SortDivDt
				strOrderBy = sqlMTI_TEST.sqlOrder_By_SortDivDt
			Case Else
		End Select
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pTestSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' SQL文の取得
	''' </summary>
	''' <param name="strSQL">SQL文</param>
	''' <returns>ORDER BY句を変更したSQL文</returns>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getSQL(ByVal strSQL As String) As String
		Try
			Return strSQL.Replace(sqlMTI_TEST.strORDER_BY, strOrderBy)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より検査情報クラスを作成
	''' </summary>
	''' <param name="pRow">検査情報 DataRow</param>
	''' <returns>検査情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestRecFromDataRow(ByVal pRow As DataRow) As datMTI_TEST_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "DataRow より検査情報クラスを作成 Start")
		Dim retDat As datMTI_TEST_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_TEST_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より検査情報＋名称クラスを作成
	''' </summary>
	''' <param name="pRow">検査情報 DataRow</param>
	''' <returns>検査情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusRecFromDataRow(ByVal pRow As DataRow) As datMTI_TEST_PLUS_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "DataRow より検査情報＋名称クラスを作成 Start")
		Dim retDat As datMTI_TEST_PLUS_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_TEST_PLUS_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Patient))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_TEST_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報（ArrayList内にdatMTI_TEST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Ch))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <returns>検査情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As datMTI_TEST_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <returns>検査情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As datMTI_TEST_OneRec
		Dim retDat As datMTI_TEST_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_TEST.prmTEST_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'検査連番
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_TEST.prmTEST_SERIAL_NO, pTestSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_TEST_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <returns>検査情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <returns>検査情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_OneRec))

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_TEST.prmTEST_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'検査連番
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_TEST.prmTEST_SERIAL_NO, pTestSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Patient))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_TEST_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報＋名称（ArrayList内にdatMTI_TEST_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Ch))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の検査情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Plus_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)					'科歴番号
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">治療処置連番</param>
	''' <returns>検査情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As datMTI_TEST_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">治療処置連番</param>
	''' <returns>検査情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As datMTI_TEST_PLUS_OneRec
		Dim retDat As datMTI_TEST_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_TEST.sqlSelTest_Plus_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_TEST.prmTest_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_TEST.prmTest_SERIAL_NO, pTestSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_TEST_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_TEST_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">治療処置連番</param>
	''' <returns>検査情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getTestPlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">治療処置連番</param>
	''' <returns>検査情報＋名称</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getTestPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_TEST.sqlSelTest_Plus_OneRec))

			db.setParamDa(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_TEST.prmTest_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'治療処置連番
			db.setValDa(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_TEST.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_TEST.prmTest_SERIAL_NO, pTestSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の検査情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelTestPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "１患者分の検査情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_TEST.sqlDelTest_Patient)	'DELETE文設定
				db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の検査情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelTestHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "１入退院分の検査情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_TEST.sqlDelTest_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の検査情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelTestCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "１科歴分の検査情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_TEST.sqlDelTest_Ch)	'DELETE文設定
				db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pTestSerialNo">検査連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelTestOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pTestSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "検査情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pTestSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_TEST.sqlDelTest_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_TEST.prmTEST_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'検査連番
				db.setVal(sqlMTI_TEST.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_TEST.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_TEST.prmTEST_SERIAL_NO, pTestSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pTestRec">検査情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pTestRec As datMTI_TEST_OneRec) As Integer
		Try
			Return execInsTestOneRec(db, pTestRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">検査情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pTestRec As datMTI_TEST_OneRec = Nothing
		Try
			Return execInsTestOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pTestRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">検査情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pTestRec As datMTI_TEST_OneRec = Nothing
		Try
			pTestRec = getTestRecFromDataRow(pRow)
			Return execInsTestOneRec(db, pTestRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pTestRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pTestPlusRec">検査情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pTestPlusRec As datMTI_TEST_PLUS_OneRec) As Integer
		Try
			Return execInsTestOneRec(db, pTestPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pTestPlusRec">検査情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pTestPlusRec As datMTI_TEST_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pTestRec As datMTI_TEST_OneRec = Nothing
		Try
			If pTestPlusRec IsNot Nothing Then
				pTestRec = pTestPlusRec.OrgCopy
			End If
			Return execInsTestOneRec(db, pTestRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pTestRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検査情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pTestRec">検査情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsTestOneRec(ByVal db As clsDB, ByVal pTestRec As datMTI_TEST_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "検査情報アクセスクラス", "検査情報１データを追加 Start")
		Try
			If pTestRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_TEST.sqlInsTest_OneRec)
			' 患者番号
			db.setParam(sqlMTI_TEST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmPATIENT_NO, pTestRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_TEST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_TEST.prmHSP_HISTORY_NO, pTestRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_TEST.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_TEST.prmCH_NO, pTestRec.CH_NO, False)
			' 検査連番
			db.setParam(sqlMTI_TEST.prmTEST_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_TEST.prmTEST_SERIAL_NO, pTestRec.TEST_SERIAL_NO, False)
			' 検査区分コード
			db.setParam(sqlMTI_TEST.prmTEST_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmTEST_DIV, pTestRec.TEST_DIV)
			' 検査名
			db.setParam(sqlMTI_TEST.prmTEST_NM, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmTEST_NM, pTestRec.TEST_NM)
			' 実施日
			db.setParam(sqlMTI_TEST.prmTEST_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_TEST.prmTEST_DT, pTestRec.TEST_DT)
			' 補助区分コード
			db.setParam(sqlMTI_TEST.prmASST_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmASST_DIV, pTestRec.ASST_DIV)
			' 備考１
			db.setParam(sqlMTI_TEST.prmREMARKS1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmREMARKS1, pTestRec.REMARKS1)
			' 備考２
			db.setParam(sqlMTI_TEST.prmREMARKS2, clsDB.Enum_dbType.dbNumeric)
			If pTestRec.REMARKS2.HasValue Then
				db.setVal(sqlMTI_TEST.prmREMARKS2, pTestRec.REMARKS2.Value, False)
			Else
				db.setVal(sqlMTI_TEST.prmREMARKS2, 0)
			End If
			' ＩＣＤ９ＣＭコード
			db.setParam(sqlMTI_TEST.prmICD9CM_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmICD9CM_CD, pTestRec.ICD9CM_CD)
			' 大分類コード
			db.setParam(sqlMTI_TEST.prmL_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmL_GRP_CD, pTestRec.L_GRP_CD)
			' 中分類コード
			db.setParam(sqlMTI_TEST.prmM_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmM_GRP_CD, pTestRec.M_GRP_CD)
			' ３桁分類コード
			db.setParam(sqlMTI_TEST.prmDIGS3_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmDIGS3_GRP_CD, pTestRec.DIGS3_GRP_CD)
			' 管理記号
			db.setParam(sqlMTI_TEST.prmMNG_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmMNG_DIV, pTestRec.MNG_DIV)
			' 管理番号
			db.setParam(sqlMTI_TEST.prmMNG_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_TEST.prmMNG_NO, pTestRec.MNG_NO, False)
			' 点数表コード
			db.setParam(sqlMTI_TEST.prmSCORE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmSCORE_CD, pTestRec.SCORE_CD)
			' 院内手術コード
			db.setParam(sqlMTI_TEST.prmHSP_OPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_TEST.prmHSP_OPE_CD, pTestRec.HSP_OPE_CD)
			' データ取込日
			db.setParam(sqlMTI_TEST.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_TEST.prmDATA_CAPTURE_DT, pTestRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_TEST.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_TEST.prmNEW_REG_DT, pTestRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_TEST.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pTestRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_TEST.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_TEST.prmLASTUPDUSER_CD, pTestRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_TEST.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pTestRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_TEST.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_TEST.prmLASTUPD_DT, pTestRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
